@@ -50,7 +50,7 @@ static const char cite_user_deepmd_package[] =
     "energy representation and molecular dynamics}},\n"
     "  pages = {178--184}\n"
     "}\n"
-    "@misc{Zeng_JChemPhys_2023_v159_p054801,\n"
+    "@article{Zeng_JChemPhys_2023_v159_p054801,\n"
     "  title  = {{DeePMD-kit v2: A software package for deep potential "
     "models}},\n"
     "  author =   {Jinzhe Zeng and Duo Zhang and Denghui Lu and Pinghui Mo and "
@@ -82,6 +82,38 @@ static const char cite_user_deepmd_package[] =
     "  year =    2023,\n"
     "  pages  =   054801,\n"
     "  doi =      {10.1063/5.0155600},\n"
+    "}\n"
+    "@Article{Zeng_arXiv_2025_p2502.19161,\n"
+    "  annote       = {general purpose},\n"
+    "    author =   {Jinzhe Zeng and Duo Zhang and Anyang Peng and Xiangyu "
+    "Zhang and Sensen\n"
+    "             He and Yan Wang and Xinzijian Liu and Hangrui Bi and Yifan "
+    "Li and Chun\n"
+    "             Cai and Chengqian Zhang and Yiming Du and Jia-Xin Zhu and "
+    "Pinghui Mo\n"
+    "             and Zhengtao Huang and Qiyu Zeng and Shaochen Shi and "
+    "Xuejian Qin and\n"
+    "             Zhaoxi Yu and Chenxing Luo and Ye Ding and Yun-Pei Liu and "
+    "Ruosong Shi\n"
+    "             and Zhenyu Wang and Sigbj{\\o}rn L{\\o}land Bore and Junhan "
+    "Chang and\n"
+    "             Zhe Deng and Zhaohan Ding and Siyuan Han and Wanrun Jiang "
+    "and Guolin\n"
+    "             Ke and Zhaoqing Liu and Denghui Lu and Koki Muraoka and "
+    "Hananeh Oliaei\n"
+    "             and Anurag Kumar Singh and Haohui Que and Weihong Xu and "
+    "Zhangmancang\n"
+    "             Xu and Yong-Bin Zhuang and Jiayu Dai and Timothy J. Giese "
+    "and Weile\n"
+    "             Jia and Ben Xu and Darrin M. York and Linfeng Zhang and Han "
+    "Wang},\n"
+    "    title =    {{DeePMD-kit v3: A Multiple-Backend Framework for Machine "
+    "Learning\n"
+    "             Potentials}},\n"
+    "    journal =  {arXiv},\n"
+    "    year =     2025,\n"
+    "    pages =    {2502.19161},\n"
+    "    doi =      {10.48550/arXiv.2502.19161},\n"
     "}\n\n";
 
 PairDeepSpin::PairDeepSpin(LAMMPS *lmp)
